==> oktan-nautika-inti-gath-0.1.3-571b83.tar: src/Wp/Plugin/GathTires.php <==
<?php
namespace Inti\Gath\Wp\Plugin;

use Inti\Gath\Model\Repository\ProductRepository;
use Inti\Gath\Model\Repository\TireRepository;
use WP_Post;
use WP_Query;

/**
 * Class GathTires
 *
 * @package Inti\Gath\Wp\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath
 */
final class GathTires extends GathMetadata
{
    /** @var TireRepository */
    private $repo;

    /**
     * Konstruktor.
     *
     * @param TireRepository $repo
     */
    public function __construct(TireRepository $repo)
    {
        $this->repo = $repo;
    }

    public function init(): void
    {
        parent::init();

        add_filter('posts_pre_query', [$this, 'get_posts'], -1, 2);
    }

    /**
     * @param $posts
     * @param WP_Query $query
     * @return WP_Post[]
     */
    public function get_posts($posts, WP_Query $query): array
    {
        // netko je već vratio postove
        if (is_array($posts) && !empty($posts)) {
            return $posts;
        }

        // ne tražimo proizvode uopće
        if (!$query->is_search() && (@$query->query_vars['wc_query'] ?? '') !== 'product_query' && $query->query_vars['post_type'] !== 'product') {
            return $posts;
        }

        if (!is_product_category() || !get_term_meta(get_queried_object_id(), 'isTireCategory', true)) {
            return $posts;
        }

        switch ($query->query_vars['orderby'] ?? '') {
            case 'stock':
                $sort = ProductRepository::SORT_STOCK_DESC;
                break;
            case 'menu_order title':
                $sort = ProductRepository::SORT_NAME_ASC;
                break;
            case 'price':
                $sort = $query->query_vars['order'] === 'DESC'
                    ? ProductRepository::SORT_PRICE_DESC
                    : ProductRepository::SORT_PRICE_ASC;
                break;
            case 'date ID':
            default:
                $sort = ProductRepository::SORT_DATE_DESC;
                break;
        }

        $limit = $query->query_vars['posts_per_page'];
        $page = max(1, intval($query->query_vars['paged']));
        $offset = ($page - 1) * $limit;



        return [];
    }
}

==> oktan-nautika-inti-gath-0.1.4-89103a.tar: src/Wp/Plugin/GathTires.php <==
<?php
namespace Inti\Gath\Wp\Plugin;

use Inti\Gath\Model\Repository\ProductRepository;
use Inti\Gath\Model\Repository\TireRepository;
use WP_Post;
use WP_Query;

/**
 * Class GathTires
 *
 * @package Inti\Gath\Wp\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath
 */
final class GathTires extends GathMetadata
{
    /** @var TireRepository */
    private $repo;

    /**
     * Konstruktor.
     *
     * @param TireRepository $repo
     */
    public function __construct(TireRepository $repo)
    {
        $this->repo = $repo;
    }

    public function run(?array $options = null): void
    {
        parent::run($options);

        add_filter('posts_pre_query', [$this, 'get_posts'], -1, 2);
    }

    /**
     * @param $posts
     * @param WP_Query $query
     * @return WP_Post[]
     */
    public function get_posts($posts, WP_Query $query): array
    {
        // netko je već vratio postove
        if (is_array($posts) && !empty($posts)) {
            return $posts;
        }

        // ne tražimo proizvode uopće
        if (!$query->is_search() && (@$query->query_vars['wc_query'] ?? '') !== 'product_query' && $query->query_vars['post_type'] !== 'product') {
            return $posts;
        }

        if (!is_product_category() || !get_term_meta(get_queried_object_id(), 'isTireCategory', true)) {
            return $posts;
        }

        switch ($query->query_vars['orderby'] ?? '') {
            case 'stock':
                $sort = ProductRepository::SORT_STOCK_DESC;
                break;
            case 'menu_order title':
                $sort = ProductRepository::SORT_NAME_ASC;
                break;
            case 'price':
                $sort = $query->query_vars['order'] === 'DESC'
                    ? ProductRepository::SORT_PRICE_DESC
                    : ProductRepository::SORT_PRICE_ASC;
                break;
            case 'date ID':
            default:
                $sort = ProductRepository::SORT_DATE_DESC;
                break;
        }

        $limit = $query->query_vars['posts_per_page'];
        $page = max(1, intval($query->query_vars['paged']));
        $offset = ($page - 1) * $limit;



        return [];
    }
}
